/**
 * Provides helper functions for converting the casing of names.
 */
export declare class NameUtility {
    /**
    * Makes the first character of the string uppercase.
    */
    static capitalize(input: string): string;
    /**
     * Makes the first character of the string lowercase.
     */
    static unCapitalize(input: string): string;
    /**
     * Converts a UpperCamelCase or lowerCamelCase string to a kebab-case (aka dash-case) string.
     * @param input A camelCase or UpperCamelCase string.
     * @returns a kebab-case (aka dash-case) string, meaning all lowercase with a dash separating words.
     */
    static camelToKebabCase(input: string): string;
    /**
     * Converts a UpperCamelCase string to a lowerCamelCase string.
     * @param input A UpperCamelCase string.
     * @returns a lowerCamelCase string.
     */
    static upperToLowerCamelCase(input: string): string;
    /**
   * Converts a lowerCamelCase string to a UpperCamelCase string.
   * @param input A lowerCamelCase string.
   * @returns a UpperCamelCase string.
   */
    static lowerToUpperCamelCase(input: string): string;
    /**
     * Converts a kebab-case, lowerCamelCase or UpperCamelCase string to an ALL_UPPER_CASE string.
     * @param input A kebab-case (aka dash-case), lowerCamelCase or UpperCamelCase string.
     * @returns an ALL_UPPER_CASE string.
     */
    static toAllUpperCase(input: string): string;
}
